==> haskell-iproute-1.7.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.1
id: iproute-1.7.1-FOMJZeVPuEXEhUtov6bEOC
key: iproute-1.7.1-FOMJZeVPuEXEhUtov6bEOC
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
abi: 3c57dfb6881ff4481dc47334d39cc8e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/iproute-1.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/iproute-1.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/iproute-1.7.1
hs-libraries: HSiproute-1.7.1-FOMJZeVPuEXEhUtov6bEOC
depends:
    base-4.10.1.0 appar-0.1.4-4hjiMZCExd3CrJSMoeXviI
    byteorder-1.0.4-C3RUhEkbWDI7bhRvbw5CmU containers-0.5.10.2
    network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             appar-0.1.4-4hjiMZCExd3CrJSMoeXviI=e8232bfdb9e1478bb139428012391ff2
             byteorder-1.0.4-C3RUhEkbWDI7bhRvbw5CmU=e5080f90f7869b94a53d4588ddacb389
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM=58be2fae16c0eb05685e5ecea6703cff
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.2
id: iproute-1.7.2-7o9K05EFyJEIptVEOLTZUq
key: iproute-1.7.2-7o9K05EFyJEIptVEOLTZUq
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
abi: ea6fdec4e01ce811d1c9109ca14403f1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/iproute-1.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/iproute-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/iproute-1.7.2
hs-libraries: HSiproute-1.7.2-7o9K05EFyJEIptVEOLTZUq
depends:
    base-4.10.1.0 appar-0.1.4-4hjiMZCExd3CrJSMoeXviI
    byteorder-1.0.4-C3RUhEkbWDI7bhRvbw5CmU containers-0.5.10.2
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             appar-0.1.4-4hjiMZCExd3CrJSMoeXviI=e8232bfdb9e1478bb139428012391ff2
             byteorder-1.0.4-C3RUhEkbWDI7bhRvbw5CmU=e5080f90f7869b94a53d4588ddacb389
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
